=======
Credits
=======

Development Lead
----------------

* Ronald Haentjens Dekker <ronald.dekker@huygens.knaw.nl>
* Gregor Middell <gregor@middell.net>

Contributors
------------

David J. Birnbaum (for Windows support and installation documentation)
Tara L. Andrews (for bugfixes and patches)
